Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
/var/devmt/py/dbilib_0.5.0/dbilib/__init__.py | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_base.py | 63 | 0 | 25 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_mysql.py | 64 | 0 | 12 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_sqlite.py | 20 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_version.py | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/database.py | 29 | 4 | 5 | 86%
Total | 178 | 4 | 42 | 98%

No items found using the specified filter.